limited_exercise_upload_stream

Function limited_exercise_upload_stream 

fn limited_exercise_upload_stream(
    field: Field,
    batch_bytes: Arc<AtomicU64>,
) -> (GenericPayload, Arc<Mutex<Option<ControllerError>>>, Arc<AtomicU64>)
Returns a side channel for typed upload-limit errors because the stream yields anyhow errors, and the running byte count of this part. Both are only meaningful once upload_stream has returned: the count is still climbing while the stream is being consumed.